@@ -12,17 +12,18 @@
 
 #include "colorid.h"
 #include "control.h"
+#include "cssmanager.h"
 
 #include <gtkmm.h>
-#include <string>
 
 namespace ARTICLE
 {
     struct LAYOUT;
     class LayoutTree;
+    class EmbeddedImage;
 
     // マウスボタンプレスとリリースのシグナル。リリース時にマウスがリンクの上にある時そのURLを渡す
-    typedef sigc::signal< bool, GdkEventButton* > SIG_BUTTON_PRESS;
+    typedef sigc::signal< bool, std::string, int, GdkEventButton* > SIG_BUTTON_PRESS;
     typedef sigc::signal< bool, std::string, int, GdkEventButton* > SIG_BUTTON_RELEASE;
 
     typedef sigc::signal< bool, GdkEventCrossing* > SIG_LEAVE_NOTIFY;
@@ -89,14 +90,12 @@ namespace ARTICLE
         // キャレット情報
         CARET_POSITION m_caret_pos;           // 現在のキャレットの位置(クリックやドラッグすると移動)
         CARET_POSITION m_caret_pos_pre;       // 移動前のキャレットの位置(選択範囲の描画などで使用する)
-        CARET_POSITION m_caret_pos_current;   // 現在のマウスポインタの下のキャレットの位置(マウスを動かすと移動)
         CARET_POSITION m_caret_pos_dragstart; // ドラッグを開始したキャレット位置
 
         // 色
-        Gdk::Color m_color[ COLOR_NUM ];
-
-        // 新着セパレータの位置(レス番号),  0 なら表示しない
-        int m_separator_new; 
+        int m_colorid_text;     // デフォルトの文字色
+        int m_colorid_back;     // デフォルトの背景色
+        std::vector< Gdk::Color > m_color;
 
         // 枠を描くか
         bool m_draw_frame;
@@ -108,20 +107,26 @@ namespace ARTICLE
         std::list< SELECTION > m_multi_selection;
       
         // レイアウト用
+        CORE::CSS_PROPERTY m_css_body; // body の cssプロパティ
+        int m_fontid;
         int m_font_ascent;
         int m_font_descent;
         int m_font_height;
         int m_underline_pos; // 下線の位置(文字の上からのピクセル値)
         int m_br_size; // 改行量 (ピクセル値)
-        int m_mrg_left; // 左マージン幅 (ピクセル値)
-        int m_mrg_right; // 右マージン幅 (ピクセル値)
-        int m_down_size; // 字下げ幅(ピクセル)
+        int m_mrg_right; // wrap計算のときに使用する右マージン幅 (ピクセル値)
+
+        // ビューのリサイズ用
+        bool m_configure_reserve; // true の時は再描画する前に再レイアウトする
+        int m_configure_width;
+        int m_configure_height;
 
         // スクロール情報
         SCROLLINFO m_scrollinfo;
         guint32 m_wheel_scroll_time; // 前回ホイールを回した時刻
         int m_goto_num_reserve; // 初期化時のジャンプ予約(レス番号)
         int m_pre_pos_y; // ひとつ前のスクロールバーの位置。スクロールした時の差分量計算に使用する
+        std::vector< int > m_jump_history;  // ジャンプ履歴
 
         // 状態
         int m_x_pointer, m_y_pointer;  // 現在のマウスポインタの位置
@@ -134,6 +139,9 @@ namespace ARTICLE
         // 入力コントローラ
         CONTROL::Control m_control;
 
+        // 埋め込み画像のポインタ
+        std::list< EmbeddedImage* > m_eimgs;
+
       public:
 
         SIG_BUTTON_PRESS sig_button_press(){ return m_sig_button_press; }
@@ -157,12 +165,33 @@ namespace ARTICLE
         void focus_view();
         void focus_out();
 
+        // フォントID( fontid.h にある ID を指定)
+        const int get_fontid() const { return m_fontid; }
+        void set_fontid( int id ){ m_fontid = id; }
+
         // 新着セパレータのあるレス番号の取得とセット
-        const int get_separator_new() const { return m_separator_new; }
-        void set_separator_new( int num ){ m_separator_new = num; };
+        const int get_separator_new();
+        void set_separator_new( int num );
+        void hide_separator_new();
+
+        // セパレータが画面に表示されているか
+        const bool is_separator_on_screen();
+
+        // 全選択
+        void select_all(); 
+
+        // 範囲選択中の文字列
+        const std::string str_selection(); 
+
+        // 範囲選択を開始したレス番号
+        const int get_selection_resnum_from();
+
+        // 範囲選択を終了したレス番号
+        const int get_selection_resnum_to();
 
-        const std::string str_selection(); // 範囲選択中の文字列
         const int get_seen_current() const { return m_seen_current; } // 現在見ているレスの番号
+        const int get_goto_num_reserve() const { return m_goto_num_reserve; } // 初期化時のジャンプ予約(レス番号)
+
         int max_number();   // 表示されている最後のレスの番号
 
         // レスをappendして再レイアウト
@@ -194,24 +223,39 @@ namespace ARTICLE
         void wheelscroll( GdkEventScroll* event );
 
         // ジャンプ
+        void set_jump_history(); // ジャンプ履歴に現在のスレを登録
         void goto_num( int num );
+        void goto_next_res();
+        void goto_pre_res();
         void goto_new();
         void goto_top();
         void goto_bottom();
+        void goto_back();
 
         // 検索
-        bool search( std::list< std::string >& list_query, bool reverse );
-        void search_move( bool reverse );
+        int search( std::list< std::string >& list_query, bool reverse );
+        int search_move( bool reverse );
         void clear_highlight();
 
       protected:
 
+        // バックスクリーン描画
+        bool draw_backscreen( bool redraw_all = false );
+
+        // 文字色のID( colorid.h にある ID を指定)
+        const int get_colorid_text() const{ return m_colorid_text; }
+        void set_colorid_text( int id ){ m_colorid_text = id; }
+
+        // 背景色のID( colorid.h にある ID を指定)
+        const int get_colorid_back();
+        void set_colorid_back( int id ){ m_colorid_back = id; }
+
         // 共通セットアップ
         void setup( bool show_abone, bool show_scrbar );
 
         // レイアウト処理
-        virtual void layout();
-        void layout_impl( bool nowrap, int offset_y, int right_mrg );
+        virtual bool exec_layout();
+        bool exec_layout_impl( bool nowrap, int offset_y, int right_mrg );
 
         // バックスクリーンをDrawAreaにコピー
         bool draw_drawarea( int x = 0, int y = 0, int width = 0, int height = 0 );
@@ -225,33 +269,34 @@ namespace ARTICLE
 
       private:
 
-        // 背景色
-        virtual const int* rgb_color_back();
-
-        // フォント
-        virtual const std::string& fontname(); 
-
-        // フォントモード
-        virtual const int fontmode();
-
         // 初期化関係
         void clear();
         void create_scrbar();
         void init_color();
         void init_font();
 
-        // 描画、レイアウト関係
-        void layout_one_node( LAYOUT* node, int& x, int& y, int width_win, int& mrg_level ); 
-        bool draw_backscreen( bool redraw_all = false ); // バックスクリーン描画
-        int get_width_of_one_char( const char* str, int& byte, char& pre_char, bool& wide_mode, const int mode );
-        void draw_one_node( LAYOUT* layout, const int& width_win, const int& pos_y );
-        void draw_one_text_node( LAYOUT* layout, const int& width_win, const int& pos_y );
-        bool set_init_wide_mode( const char* str, const int pos_start, const int pos_to );
-        bool is_wrapped( const int x, const int boarder, const char* str );
-        void layout_draw_one_node( LAYOUT* node, int& node_x, int& node_y, int& node_width, int& node_height,
-                                   int width_view, bool do_draw, bool bold = false, 
-                                   int color = COLOR_CHAR, int color_back = COLOR_BACK, int byte_from = 0, int byte_to = 0 );
+        // レイアウト処理
+        void set_align( LAYOUT* div, int id_end, int align );
+        void set_align_line( LAYOUT* div, LAYOUT* layout_from, LAYOUT* layout_to, RECTANGLE* rect_from, RECTANGLE* rect_to,
+                             int width_line, int align );
+        void layout_one_text_node( LAYOUT* node, int& node_x, int& node_y, int& br_size, const int width_view );
+        void layout_one_img_node( LAYOUT* node, int& node_x, int& node_y, int& brsize, const int width_view );
 
+        // 文字の幅などの情報
+        int get_width_of_one_char( const char* str, int& byte, char& pre_char, bool& wide_mode, const int mode );
+        bool set_init_wide_mode( const char* str, const int pos_start, const int pos_to );
+        bool is_wrapped( const int x, const int border, const char* str );
+
+        // 描画
+        bool draw_one_node( LAYOUT* layout, const int width_win, const int pos_y, const int upper, const int lower );
+        void draw_div( LAYOUT* layout_div, const int pos_y, const int upper, const int lower );
+        void draw_one_text_node( LAYOUT* layout, const int width_win, const int pos_y );
+        void draw_string( LAYOUT* node, const int pos_y, const int width_view,
+                          const int color, const int color_back, const int byte_from, const int byte_to );
+        bool draw_one_img_node( LAYOUT* layout, const int pos_y );
+
+        // drawarea がリサイズ実行
+        void configure_impl();
 
         // 整数 -> 文字変換してノードに発言数をセット
         int set_num_id( LAYOUT* layout );
@@ -262,13 +307,17 @@ namespace ARTICLE
         int get_vscr_maxval();
 
         // キャレット関係
+        bool is_pointer_on_rect( const RECTANGLE* rect, const char* text, const int pos_start, const int pos_to,
+                                 const int x, const int y,
+                                 int& pos, int& width_line, int& char_width, int& byte_char );
         LAYOUT* set_caret( CARET_POSITION& caret_pos, int x, int y );
         bool set_carets_dclick( CARET_POSITION& caret_left, CARET_POSITION& caret_right,  int x, int y );
 
         // 範囲選択関係
-        bool set_selection( CARET_POSITION& caret_left, CARET_POSITION& caret_right );
-        bool set_selection( CARET_POSITION& caret_pos, bool redraw = true );
+        bool set_selection( CARET_POSITION& caret_left, CARET_POSITION& caret_right, const bool redraw = true );
+        bool set_selection( CARET_POSITION& caret_pos, const bool redraw = true );
         bool set_selection_str();
+        const bool is_caret_on_selection( const CARET_POSITION& caret_pos );
         std::string get_selection_as_url( const CARET_POSITION& caret_pos );
 
         // マウスが動いた時の処理
