@@ -17,14 +17,18 @@
 #include "colorid.h"
 #include "cssmanager.h"
 
-#define SIZE_OF_HEAP 256 * 1024
+enum
+{
+    SIZE_OF_HEAP = 256 * 1024,
+
+    STEP_ID = 10,
+    STEP_SEPARATOR = 1,
+
+    MAX_IMGITEM = 512 // struct IMGDATA.item[] のサイズ
+};
 
-#define STEP_ID 10
-#define STEP_SEPARATOR 1
 
 // 埋め込み画像用構造体
-#define MAX_IMGITEM 512
-
 namespace ARTICLE
 {
     struct IMGITEM
@@ -468,6 +472,7 @@ void LayoutTree::append_html( const std::string& html )
 //
 void LayoutTree::append_dat( const std::string& dat, int num )
 {
+    if( dat.empty() ) return;
     if( ! m_local_nodetree ) m_local_nodetree = new DBTREE::NodeTreeBase( m_url, std::string() );
 
     // ダミーのノードを作って番号を調整する
@@ -476,8 +481,15 @@ void LayoutTree::append_dat( const std::string& dat, int num )
         for(int i = res_num +1 ; i <= num -1; ++i )  m_local_nodetree->append_dat( "<>broken<>\n" );
     }
 
-    DBTREE::NODE* node = m_local_nodetree->append_dat( dat );
-    append_node( node, false );
+    // 改行毎に dat を分割して追加
+    std::list< std::string > lines = MISC::get_lines( dat );
+    std::list< std::string >::iterator it = lines.begin();
+    for( ; it != lines.end(); ++it ){
+        if( ! ( *it ).empty() ){
+            DBTREE::NODE* node = m_local_nodetree->append_dat( (*it) + "\n" );
+            append_node( node, false );
+        }
+    }
 }
 
 
