@@ -11,6 +11,7 @@
 #include "dbtree/interface.h"
 
 #include "jdlib/miscutil.h"
+#include "jdlib/miscgtk.h"
 
 #include "command.h"
 #include "session.h"
@@ -20,9 +21,11 @@
 #include "updatemanager.h"
 
 
-#define MOVETAB_MENU { 5, 10, 15, 20, 25, 30 }
-        
-#define MAX_TABS 50
+enum
+{
+    MAX_TABS = 50
+};
+
 
 using namespace SKELETON;
 
@@ -94,27 +97,27 @@ void Admin::setup_menu( const bool enable_checkupdate )
     m_action_group = Gtk::ActionGroup::create();
     m_action_group->add( Gtk::Action::create( "Quit", "Quit" ), sigc::mem_fun( *this, &Admin::slot_close_tab ) );
 
-    m_action_group->add( Gtk::ToggleAction::create( "LockTab", "タブをロックする", std::string(), false ),
+    m_action_group->add( Gtk::ToggleAction::create( "LockTab", "タブをロックする(_L)", std::string(), false ),
                          sigc::mem_fun( *this, &Admin::slot_lock ) );
 
-    m_action_group->add( Gtk::Action::create( "Close_Tab_Menu", "複数のタブを閉じる" ) );
-    m_action_group->add( Gtk::Action::create( "CloseOther", "他のタブ" ), sigc::mem_fun( *this, &Admin::slot_close_other_tabs ) );
-    m_action_group->add( Gtk::Action::create( "CloseLeft", "左←のタブ" ), sigc::mem_fun( *this, &Admin::slot_close_left_tabs ) );
-    m_action_group->add( Gtk::Action::create( "CloseRight", "右→のタブ" ), sigc::mem_fun( *this, &Admin::slot_close_right_tabs ) );
-    m_action_group->add( Gtk::Action::create( "CloseAll", "全てのタブ" ), sigc::mem_fun( *this, &Admin::slot_close_all_tabs ) );
+    m_action_group->add( Gtk::Action::create( "Close_Tab_Menu", "複数のタブを閉じる(_M)" ) );
+    m_action_group->add( Gtk::Action::create( "CloseOther", "他のタブ(_O)" ), sigc::mem_fun( *this, &Admin::slot_close_other_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CloseLeft", "左←のタブ(_L)" ), sigc::mem_fun( *this, &Admin::slot_close_left_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CloseRight", "右→のタブ(_R)" ), sigc::mem_fun( *this, &Admin::slot_close_right_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CloseAll", "全てのタブ(_A)" ), sigc::mem_fun( *this, &Admin::slot_close_all_tabs ) );
 
-    m_action_group->add( Gtk::Action::create( "Reload_Tab_Menu", "全てのタブの再読み込み" ) );
-    m_action_group->add( Gtk::Action::create( "CheckUpdateAll", "更新チェックのみ" ), sigc::mem_fun( *this, &Admin::slot_check_update_all_tabs ) );
-    m_action_group->add( Gtk::Action::create( "CheckUpdateReloadAll", "更新されたタブを再読み込み" ),
+    m_action_group->add( Gtk::Action::create( "Reload_Tab_Menu", "全てのタブの再読み込み(_A)" ) );
+    m_action_group->add( Gtk::Action::create( "CheckUpdateAll", "更新チェックのみ(_U)" ), sigc::mem_fun( *this, &Admin::slot_check_update_all_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CheckUpdateReloadAll", "更新されたタブを再読み込み(_A)" ),
                          sigc::mem_fun( *this, &Admin::slot_check_update_reload_all_tabs ) );
-    m_action_group->add( Gtk::Action::create( "ReloadAll", "再読み込み" ), sigc::mem_fun( *this, &Admin::slot_reload_all_tabs ) );
-    m_action_group->add( Gtk::Action::create( "CancelReloadAll", "キャンセル" ), sigc::mem_fun( *this, &Admin::slot_cancel_reload_all_tabs ) );
+    m_action_group->add( Gtk::Action::create( "ReloadAll", "再読み込み(_R)" ), sigc::mem_fun( *this, &Admin::slot_reload_all_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CancelReloadAll", "キャンセル(_C)" ), sigc::mem_fun( *this, &Admin::slot_cancel_reload_all_tabs ) );
 
-    m_action_group->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く" ), sigc::mem_fun( *this, &Admin::slot_open_by_browser ) );
-    m_action_group->add( Gtk::Action::create( "CopyURL", "URLをコピー" ), sigc::mem_fun( *this, &Admin::slot_copy_url ) );
-    m_action_group->add( Gtk::Action::create( "CopyTitle", "タイトルとURLをコピー" ), sigc::mem_fun( *this, &Admin::slot_copy_title_url ) );
+    m_action_group->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く(_W)" ), sigc::mem_fun( *this, &Admin::slot_open_by_browser ) );
+    m_action_group->add( Gtk::Action::create( "CopyURL", "URLをコピー(_U)" ), sigc::mem_fun( *this, &Admin::slot_copy_url ) );
+    m_action_group->add( Gtk::Action::create( "CopyTitle", "タイトルとURLをコピー(_T)" ), sigc::mem_fun( *this, &Admin::slot_copy_title_url ) );
 
-    m_action_group->add( Gtk::Action::create( "Preference", "プロパティ..."), sigc::mem_fun( *this, &Admin::show_preference ) );
+    m_action_group->add( Gtk::Action::create( "Preference", "プロパティ(_P)..."), sigc::mem_fun( *this, &Admin::show_preference ) );
 
     m_ui_manager = Gtk::UIManager::create();    
     m_ui_manager->insert_action_group( m_action_group );
@@ -189,11 +192,11 @@ void Admin::setup_menu( const bool enable_checkupdate )
     m_move_menu = Gtk::manage( new Gtk::Menu() );
 
     // 先頭、最後に移動
-    item = Gtk::manage( new Gtk::MenuItem( "先頭に移動" ) );
+    item = Gtk::manage( new Gtk::MenuItem( "先頭に移動(_H)", true ) );
     m_move_menu->append( *item );
     item->signal_activate().connect( sigc::mem_fun( *this, &Admin::tab_head ) );
 
-    item = Gtk::manage( new Gtk::MenuItem( "最後に移動" ) );
+    item = Gtk::manage( new Gtk::MenuItem( "最後に移動(_T)", true ) );
     m_move_menu->append( *item );
     item->signal_activate().connect( sigc::mem_fun( *this, &Admin::tab_tail ) );
     m_move_menu->append( *Gtk::manage( new Gtk::SeparatorMenuItem() ) );
@@ -465,6 +468,9 @@ void Admin::exec_command()
     else if( command.command == "redraw_current_view" ){
         redraw_current_view();
     }
+    else if( command.command == "relayout_current_view" ){
+        relayout_current_view();
+    }
     // command.url を含むview全てを検索して表示中なら再描画
     else if( command.command == "redraw_views" ){
         redraw_views( command.url );
@@ -567,6 +573,11 @@ void Admin::exec_command()
         toggle_toolbar();
     }
 
+    // ツールバーボタン表示更新
+    else if( command.command == "update_toolbar" ){
+        update_toolbar();
+    }
+
     // タブ表示切り替え
     else if( command.command == "toggle_tab" ){
         toggle_tab();
@@ -886,6 +897,20 @@ void Admin::redraw_current_view()
 }
 
 
+//
+// 現在のビューを再レイアウト
+//
+void Admin::relayout_current_view()
+{
+#ifdef _DEBUG
+    std::cout << "Admin::relayout_current_view : " << m_url << std::endl;
+#endif
+
+    SKELETON::View* view = get_current_view();
+    if( view ) view->relayout();
+}
+
+
 //
 // urlを含むビューを検索してそれがカレントならば再描画
 //
@@ -1230,6 +1255,20 @@ void Admin::toggle_toolbar()
 }
 
 
+//
+// ツールバーボタン表示更新
+//
+void Admin::update_toolbar()
+{
+    std::list< SKELETON::View* > list_view = get_list_view();
+    std::list< SKELETON::View* >::iterator it = list_view.begin();
+    for( ; it != list_view.end(); ++it ){
+        SKELETON::View* view = ( *it );
+        if( view ) view->update_toolbar();
+    }
+}
+
+
 //
 // タブ表示切り替え
 //
@@ -1421,6 +1460,10 @@ std::string Admin::get_current_url()
 //
 void Admin::slot_switch_page( GtkNotebookPage*, guint page )
 {
+    // 起動中とシャットダウン中は処理しない
+    if( SESSION::is_booting() ) return;
+    if( SESSION::is_quitting() ) return;
+
 #ifdef _DEBUG
     std::cout << "Admin::slot_switch_page : " << m_url << " page = " << page << std::endl;
 #endif
@@ -1504,9 +1547,14 @@ void Admin::slot_tab_menu( int page, int x, int y )
     act = m_action_group->get_action( "LockTab" );
     if( page >= 0 && act ){
 
-        Glib::RefPtr< Gtk::ToggleAction > tact = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( act ); 
-        if( is_locked( page ) ) tact->set_active( true );
-        else tact->set_active( false );
+        if( ! is_lockable( page ) ) act->set_sensitive( false );
+        else{
+            act->set_sensitive( true );
+
+            Glib::RefPtr< Gtk::ToggleAction > tact = Glib::RefPtr< Gtk::ToggleAction >::cast_dynamic( act ); 
+            if( is_locked( page ) ) tact->set_active( true );
+            else tact->set_active( false );
+        }
     }
 
     // 閉じる
@@ -1535,10 +1583,9 @@ void Admin::slot_tab_menu( int page, int x, int y )
             if( label ){
 
                 std::string name = m_notebook->get_tab_fulltext( i );
-                if( ! name.empty() ){
-                    const unsigned int maxsize = 50;
-                    label->set_text( MISC::cut_str( name, maxsize ) );
-                }
+                if( name.empty() ) name = "???";
+                const unsigned int maxsize = 50;
+                label->set_text( MISC::cut_str( name, maxsize ) );
             }
             m_move_menu->append( *m_vec_movemenu_items[ i ] );
             m_vec_movemenu_append[ i ] = true;
@@ -1796,7 +1843,7 @@ void Admin::slot_open_by_browser()
 void Admin::slot_copy_url()
 {
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( m_clicked_page ) );
-    if( view ) COPYCLIP( view->url_for_copy() );
+    if( view ) MISC::CopyClipboard( view->url_for_copy() );
 }
 
 
@@ -1810,7 +1857,7 @@ void Admin::slot_copy_title_url()
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( m_clicked_page ) );
     if( view ) str += "\n" + view->url_for_copy();
     
-    COPYCLIP( str );
+    MISC::CopyClipboard( str );
 }
 
 
@@ -1828,6 +1875,14 @@ std::list< bool > Admin::get_locked()
 }
 
 // タブのロック/アンロック
+const bool Admin::is_lockable( const int page )
+{
+    SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
+    if( view ) return view->is_lockable();
+
+    return false;
+}
+
 const bool Admin::is_locked( const int page )
 {
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
